===============
rhaptos2.common
===============

Library of common files / functions across the Rhaptos2 world

How should we integrate with rhaptos1?

* conf.py 

  simple handling of configurations settings, checking
  ENVVAR first, then defaulting to a known config file

* exceptions
  TBC

* logging
  TBC

